@@ -156,9 +156,8 @@ class Node(BaseModel):
                 self.cache.remove(name)
         if not self.cache.exists(name):
             root_resolver = self.get_root_resolver()
-            get_params = self.GQL.GetParams(id=self.id)
             edge_params = self.GQL.Edges.parse_obj({name: resolver})
-            obj = root_resolver(edges=edge_params).get(get_params)
+            obj = root_resolver(edges=edge_params)._get(kwargs_d={"id": self.id})
             self.cache.replace(key=name, cache=obj.cache.get(name))
         return self.cache.get_val(name)
 
